<!-- markdownlint-disable -->

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.code_editor.code_editor`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**


---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `CodeEditor`




<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L5"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.__init__`

```python
__init__(*args, changed=None, model=None, highlighter=None, **kwargs)
```








---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L43"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.eventFilter`

```python
eventFilter(obj, event)
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L138"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.expand_selection`

```python
expand_selection(cursor)
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L243"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.indent_selection`

```python
indent_selection(direction)
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L56"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.insert_completion`

```python
insert_completion(completion)
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L69"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.keyPressEvent`

```python
keyPressEvent(event: PySide6.QtGui.QKeyEvent)
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L187"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.move_selection`

```python
move_selection(direction)
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L309"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.text`

```python
text()
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L64"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.text_under_cursor`

```python
text_under_cursor()
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L141"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.toggle_comments`

```python
toggle_comments()
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L50"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.update_tab_width`

```python
update_tab_width()
```





---

<a href="..\..\qtstrap\extras\code_editor\code_editor.py#L292"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `CodeEditor.wrap_selection`

```python
wrap_selection(key)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
